@@ -207,9 +207,9 @@ xfce_shortcut_dialog_create_contents (XfceShortcutDialog *dialog,
   const gchar *action_type;
   const gchar *title;
   const gchar *icon_name;
-  const gchar *explanation_label;
   const gchar *text;
   const gchar *format;
+  gchar       *explanation_label;
   gchar       *markup;
 
   if (g_utf8_collate (provider, "xfwm4") == 0)
@@ -278,6 +278,7 @@ xfce_shortcut_dialog_create_contents (XfceShortcutDialog *dialog,
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
   gtk_container_add (GTK_CONTAINER (content_box), label);
   gtk_widget_show (label);
+  g_free (explanation_label);
 
   /* Box and labels to display the shortcut currently being grabbed.
    * It will be updated to key-press events. */
@@ -431,7 +432,7 @@ xfce_shortcut_dialog_key_pressed (XfceShortcutDialog *dialog,
   g_free (escaped_label);
   g_strfreev (keys);
 
-  return FALSE;
+  return TRUE;
 }
 
 
@@ -472,7 +473,7 @@ xfce_shortcut_dialog_key_released (XfceShortcutDialog *dialog,
       gtk_widget_hide (dialog->key_box);
     }
 
-  return FALSE;
+  return TRUE;
 }
 
 
